import { VssueAPI, VssueAPIOptions } from 'vssue';
import { AxiosInstance } from 'axios';
/**
 * @see https://docs.gitlab.com/ce/api/oauth2.html
 * @see https://docs.gitlab.com/ce/api/issues.html
 * @see https://docs.gitlab.com/ce/api/notes.html
 * @see https://docs.gitlab.com/ce/api/award_emoji.html
 */
export default class GitlabV4 implements VssueAPI.Instance {
    baseURL: string;
    owner: string;
    repo: string;
    labels: string;
    clientId: string;
    clientSecret: string;
    state: string;
    $http: AxiosInstance;
    private _encodedRepo;
    constructor({ baseURL, owner, repo, labels, clientId, clientSecret, state, }: VssueAPIOptions);
    /**
     * The platform api info
     */
    readonly platform: VssueAPI.Platform;
    /**
     * Redirect to the authorization page of platform.
     */
    redirectAuth(): void;
    /**
     * Handle authorization.
     *
     * @remarks
     * If the `code` and `state` exist in the query, and the `state` matches, remove them from query, and try to get the access token.
     *
     * @return A string for access token, `null` for no authorization code
     */
    handleAuth(): Promise<string | null>;
    /**
     * Get user access token via `code`
     *
     * @param options.code - The code from the query
     *
     * @return User access token
     */
    getAccessToken({ code }: {
        code: string;
    }): Promise<string>;
    /**
     * Get the logined user with access token.
     *
     * @param options.accessToken - User access token
     *
     * @return The user
     */
    getUser({ accessToken }: {
        accessToken: any;
    }): Promise<VssueAPI.User>;
    /**
     * Get issue of this page according to the issue id or the issue title
     *
     * @param options.accessToken - User access token
     * @param options.issueId - The id of issue
     * @param options.issueTitle - The title of issue
     *
     * @return The raw response of issue
     */
    getIssue({ accessToken, issueId, issueTitle, }: {
        accessToken: any;
        issueId: any;
        issueTitle: any;
    }): Promise<VssueAPI.Issue | null>;
    /**
     * Get comments of this page according to the issue id or the issue title
     *
     * @param options.accessToken - User access token
     * @param options.issueId - The id of issue
     * @param options.query - The query parameters
     *
     * @return The comments
     */
    getComments({ accessToken, issueId, query: { page, perPage, sort, }, }: {
        accessToken: any;
        issueId: any;
        query?: {
            page?: number | undefined;
            perPage?: number | undefined;
            sort?: string | undefined;
        } | undefined;
    }): Promise<VssueAPI.Comments>;
    /**
     * Get the parse HTML of markdown content
     *
     * @param options.accessToken - User access token
     * @param options.contentRaw - The id of issue
     *
     * @return `true` if succeed, `false` if failed
     */
    getMarkdownContent({ accessToken, contentRaw, }: {
        accessToken?: string | null;
        contentRaw: string;
    }): Promise<string>;
    /**
     * Get reactions of a cooment
     *
     * @param options.accessToken - User access token
     * @param options.issueId - The id of issue
     * @param options.commentId - The id of comment
     *
     * @return The comments
     */
    getCommentReactions({ accessToken, issueId, commentId, }: {
        accessToken: any;
        issueId: any;
        commentId: any;
    }): Promise<VssueAPI.Reactions>;
    /**
     * Create a new issue
     *
     * @param options.accessToken - User access token
     * @param options.title - The title of issue
     * @param options.content - The content of issue
     *
     * @return The created issue
     */
    createIssue({ accessToken, title, content, }: {
        accessToken: any;
        title: any;
        content: any;
    }): Promise<VssueAPI.Issue>;
    /**
     * Create a new comment
     *
     * @param options.accessToken - User access token
     * @param options.issueId - The id of issue
     * @param options.content - The content of comment
     *
     * @return The created comment
     */
    createComment({ accessToken, issueId, content, }: {
        accessToken: any;
        issueId: any;
        content: any;
    }): Promise<VssueAPI.Comment>;
    /**
     * Create a new reaction of issue
     *
     * @param options.accessToken - User access token
     * @param options.issueId - The id of issue
     * @param options.reaction - The reaction
     *
     * @return `true` if succeed, `false` if already token
     */
    createIssueReaction({ accessToken, issueId, reaction, }: {
        accessToken: any;
        issueId: any;
        reaction: any;
    }): Promise<boolean>;
    /**
     * Create a new reaction of comment
     *
     * @param options.accessToken - User access token
     * @param options.issueId - The id of issue
     * @param options.commentId - The id of comment
     * @param options.reaction - The reaction
     *
     * @return `true` if succeed, `false` if already token
     */
    createCommentReaction({ issueId, commentId, reaction, accessToken, }: {
        issueId: any;
        commentId: any;
        reaction: any;
        accessToken: any;
    }): Promise<boolean>;
}
